#include "NetTool.h"

NetWindow::NetWindow ( BRect frame, char *applocation )
	: BWindow ( frame, "NetLookup", B_DOCUMENT_WINDOW, 0)
{
	BMenu		*menu;
	BMenuItem	*menuItem;
	BButton		*aButton;
	BRect		aRect;
	BString		buttonName, buttonLabel;
	const rgb_color GRAY_BG     = { 220, 220, 220, 255 };
	
	fAppLocation.SetTo (applocation);
	
	aRect = Bounds ();
	aRect.bottom = MENU_BAR_HEIGHT;
	fMenuBar = new BMenuBar (aRect, "MenuBar");
	AddChild (fMenuBar);
	
	menu = new BMenu ("File");
	fMenuBar->AddItem (menu);
	menu->AddItem (menuItem = new BMenuItem ("About", new BMessage (MENU_ABOUT_MSG), 'A', 0));
	menu->AddItem (menuItem = new BMenuItem ("Options", new BMessage (MENU_PREFS_MSG), 'O', 0));
	menu->AddSeparatorItem ();
	menu->AddItem (menuItem = new BMenuItem ("Quit", new BMessage (MENU_QUIT_MSG), 'Q', 0));

	frame.OffsetTo (B_ORIGIN);
	frame.top = MENU_BAR_HEIGHT;
	fMainView = new BView (frame, "MainView", B_FOLLOW_ALL, B_WILL_DRAW);

	Lock ();
	AddChild (fMainView);
	Unlock ();

	fMainView->SetViewColor (GRAY_BG);
	
	fMainBB = new BBox (BRect(5,5,frame.Width()-5,frame.Height()-5), NULL, B_FOLLOW_ALL, B_WILL_DRAW, B_FANCY_BORDER);
	fMainView->AddChild (fMainBB);

	
	fTextField = new BTextControl (BRect(10.0, 10.0, 280, 40.0), "TextField", "Host: ", "", new BMessage(TEXT_FIELD_MSG));
	fTextField->SetDivider (25.0);
	fMainBB->AddChild (fTextField);
	fTextField->MakeFocus(true);
	
	buttonName.SetTo ("dnsButton");
	buttonLabel.SetTo ("Host <-> IP");
	aButton = new BButton (BRect(25.0, 35.0, 105.0, 50.0), buttonName.String (), buttonLabel.String (), new BMessage(DNS_BUTTON_MSG), B_FOLLOW_TOP, B_WILL_DRAW | B_NAVIGABLE);
	aButton->MakeDefault (true);
	fMainBB->AddChild (aButton);

	buttonName.SetTo ("scanButton");
	buttonLabel.SetTo ("Portscan");
	aButton = new BButton (BRect(120.0, 35.0, 190.0, 50.0), buttonName.String (), buttonLabel.String (), new BMessage(SCAN_BUTTON_MSG), B_FOLLOW_TOP, B_WILL_DRAW | B_NAVIGABLE);
	fMainBB->AddChild (aButton);

	buttonName.SetTo ("pingButton");
	buttonLabel.SetTo ("Ping");
	aButton = new BButton (BRect(200.0, 35.0, 260.0, 50.0), buttonName.String (), buttonLabel.String (), new BMessage(PING_BUTTON_MSG), B_FOLLOW_TOP, B_WILL_DRAW | B_NAVIGABLE);
	fMainBB->AddChild (aButton);

	aRect.Set (10.0, 70.0, frame.Width()-20-B_V_SCROLL_BAR_WIDTH, frame.Height()-55);
	fStatusTextView = new BTextView (aRect, "StatusText", BRect(0.0, 0.0, aRect.Width(), aRect.Height()), B_FOLLOW_ALL_SIDES, B_WILL_DRAW|B_PULSE_NEEDED);
	fStatusTextView->MakeEditable (false);
	fStatusTextView->MakeSelectable (true);

	fScrollView = new BScrollView ("StatusScroll", fStatusTextView, B_FOLLOW_ALL_SIDES, 0, false, true, B_NO_BORDER);
	fMainBB->AddChild (fScrollView);

	fStatusBar = new BStatusBar (BRect(10, frame.Height()-54, frame.Width()-60, frame.Height()-30), "StatusBar", NULL, NULL);
	fStatusBar->SetBarHeight (8);
	fMainBB->AddChild (fStatusBar);

	fCancelOpButton = new BButton (BRect(frame.Width()-55, frame.Height()-48, frame.Width()-20, frame.Height()-30), "StopButton", "Stop", new BMessage (CANCELOP_MSG), B_FOLLOW_LEFT | B_FOLLOW_TOP, B_WILL_DRAW | B_NAVIGABLE);
	fCancelOpButton->SetEnabled(false);
	fMainBB->AddChild (fCancelOpButton);

	prefs = new PrefsDB((char *)fAppLocation.String());
	if ( prefs->InitCheck() != B_OK ) {
		PrefsError ("can't create/open prefs file", fAppLocation.String());
	}

	ReadPrefs ();
	WritePrefs ();
	
	MoveTo (windowx, windowy);
	ResizeTo (windoww, windowh);

	aRect = Bounds ();
	aRect.bottom = MENU_BAR_HEIGHT;
	fMenuBar->Draw(aRect);

	opinprogress = false;
	
	Show ();
}

void NetWindow::FrameMoved ( BPoint origin ) {
//	windowx = (int)origin.x;
//	windowy = (int)origin.y;
//	WriteWindowMovedPrefs ();
}

void NetWindow::FrameResized ( float width, float height ) {
	fMainBB->RemoveChild (fStatusBar);
	fMainBB->RemoveChild (fCancelOpButton);

	float cursbpos = fStatusBar->CurrentValue ();
	fStatusBar = new BStatusBar (BRect(10, height-(54+MENU_BAR_HEIGHT), width-60, height-(30+MENU_BAR_HEIGHT)), "StatusBar", NULL, NULL);
	fStatusBar->SetBarHeight (8);
	fMainBB->AddChild (fStatusBar);

	fStatusBar->Update (cursbpos, NULL, NULL);

	fCancelOpButton = new BButton (BRect(width-55, height-(48+MENU_BAR_HEIGHT), width-20, height-(30+MENU_BAR_HEIGHT)), "StopButton", "Stop", new BMessage (CANCELOP_MSG), B_FOLLOW_LEFT | B_FOLLOW_TOP, B_WILL_DRAW | B_NAVIGABLE);
	if ( opinprogress == false ) {
		fCancelOpButton->SetEnabled(false);
	}
	fMainBB->AddChild (fCancelOpButton);

	fMainBB->FrameResized(width, height);
	
//	WriteWindowResizedPrefs ();
}

bool NetWindow::ParseTextField (bool errfail)
{
	BString		hostTextBuf (fTextField->Text());

	if ( hostTextBuf.Length () < 1 ) {
		return false;
	}
	if ( strspn (hostTextBuf.String (), "0123456789.") < (uint)hostTextBuf.Length () ) {
		GetIP (hostTextBuf.String (), errfail);
	} else {
		GetName (hostTextBuf.String (), errfail);
	}
return true;
}

bool NetWindow::QuitRequested ()
{
	WriteWindowMovedPrefs ();
	WriteWindowResizedPrefs ();
	be_app->PostMessage (B_QUIT_REQUESTED);
	return (true);
}
