#include "NetTool.h"

void NetWindow::MessageReceived (BMessage *message)
{
	bool statusUpdate = false;
	int portnum = 0;
	int sbpos = 0;
	char	textbuf[20];
	
	switch (message->what) {
		case HOST_NOT_FOUND_MSG:
			fStatusText << message->FindString("error_text") << "\n\n";
			fStatusTextView->SetText (fStatusText.String(), fStatusText.Length(), NULL);
			fStatusTextView->ScrollTo (0, 10000);
			break;
		case PINGTHREAD_EXIT:
			memset (textbuf, 0, sizeof(textbuf));
			sprintf (textbuf, "%2.3f", message->FindDouble("minttime"));
			fStatusText << "Round Trip Time (min/avg/max): " << textbuf << " / ";
			memset (textbuf, 0, sizeof(textbuf));
			sprintf (textbuf, "%2.3f", message->FindDouble("avgttime"));
			fStatusText << textbuf << " / ";
			memset (textbuf, 0, sizeof(textbuf));
			sprintf (textbuf, "%2.3f", message->FindDouble("maxttime"));
			fStatusText << textbuf << "\n";
			fStatusText << message->FindString("pingstats") << " packets returned\n\n";
			opinprogress = false;
			fCancelOpButton->SetEnabled(false);
			fStatusTextView->SetText (fStatusText.String(), fStatusText.Length(), NULL);
			fStatusTextView->ScrollTo (0, 10000);
			fStatusBar->Reset (NULL, NULL);
			break;
		case PINGDATA_MSG:
			fStatusText << message->FindString ("result");
			fStatusTextView->SetText (fStatusText.String(), fStatusText.Length(), NULL);
			fStatusTextView->ScrollTo (0, 10000);
			if ( (sbpos = message->FindInt8 ("sbupdate")) != 0 ) {
				fStatusBar->Update (sbpos, NULL, NULL);
			}
			break;
		case CANCELOP_MSG:
			if ( KillTCPScanner() == false ) {
				if ( KillUDPScanner() == false ) {
					KillPinger ();
				}
			}
			fStatusText << "\nKilled\n";
			statusUpdate = true;
			fStatusBar->Reset (NULL, NULL);
			opinprogress = false;
			fCancelOpButton->SetEnabled(false);
			break;
		case THREAD_EXIT:
			if ( message->FindInt8 ("istcp") == 1 ) {
				if ( udp_scan == true ) {
					fStatusText << "\nudp: ";
					numuports = 0;
					SpawnUDPScanner ();
				} else {
					fStatusText << "\nNumber of open ports: " << numtports << "/tcp\n\n";
					fCancelOpButton->SetEnabled(false);
					opinprogress = false;
				}
			} else {
				fStatusText << "\nNumber of open ports: " << numtports << "/tcp " << numuports << "/udp\n\n" ;
				opinprogress = false;
				fCancelOpButton->SetEnabled(false);
			}
			fStatusTextView->SetText (fStatusText.String(), fStatusText.Length(), NULL);
			fStatusTextView->ScrollTo (0, 10000);
			fStatusBar->Reset (NULL, NULL);
			break;
		case PORTFOUND_MSG:
			if ( (portnum = message->FindInt32 ("portnum")) != 0 ) {
					if ( message->FindInt8 ("istcp") == 1 ) {
						numtports++;
					} else {
						numuports++;
					}
					fStatusText << portnum << "  ";
					fStatusTextView->SetText (fStatusText.String(), fStatusText.Length(), NULL);
					fStatusTextView->ScrollTo (0, 10000);
			}
			if ( (sbpos = message->FindInt8 ("sbupdate")) != 0 ) {
				fStatusBar->Update (sbpos, NULL, NULL);
			}
			break;
		case DNS_BUTTON_MSG:
			if ( opinprogress == false ) {
				if ( ParseTextField (true) == true ) {
					if ( fHostName.Length () > 0 ) {
						statusUpdate = true;
						DNSLookup ();
					}
				}
			}
			break;
		case SCAN_BUTTON_MSG:
			if ( opinprogress == false ) {
				if ( ParseTextField (false) == true ) {
					if ( fHostIP.Length () > 0 ) {
						statusUpdate = false;
						opinprogress = true;
						fCancelOpButton->SetEnabled(true);
						if ( Portscan () == false ) {
							opinprogress = false;
							fCancelOpButton->SetEnabled(false);
						}
					}
				}
			}
			break;
		case PING_BUTTON_MSG:
			if ( opinprogress == false ) {
				if ( ParseTextField (false) == true ) {
					if ( fHostIP.Length () > 0 ) {
						opinprogress = true;
						fCancelOpButton->SetEnabled(true);
						PingMaster ();
						fStatusTextView->SetText (fStatusText.String(), fStatusText.Length(), NULL);
						fStatusTextView->ScrollTo (0, 10000);
					}
				}
			}
			break;
		case TEXT_FIELD_MSG:
			break;
		case MENU_ABOUT_MSG:
			AboutMenu ();
			break;
		case MENU_PREFS_MSG:
			PrefsMenu ();
			break;
		case MENU_QUIT_MSG:
			QuitRequested ();
			break;
		case NEW_PREFS_MSG:
			if ( (num_pings = message->FindInt32 ("num_pings")) == 0 ) {
				num_pings = DEF_NUMPINGS;
			}
			if ( (ping_size = message->FindInt32 ("ping_size")) == 0 ) {
				ping_size = DEF_PINGSIZE;
			}
			if ( ping_size > MAX_PINGSIZE ) {
				ping_size = MAX_PINGSIZE;
			}
			if ( (start_port = message->FindInt32 ("start_port")) == 0 ) {
				start_port = DEF_STARTPORT;
			}
			if ( (end_port = message->FindInt32 ("end_port")) == 0 ) {
				end_port = DEF_ENDPORT;
			}
			if ( start_port > end_port ) {
				end_port = start_port;
			}
			pre_ping = message->FindBool ("pre_ping");
			udp_scan = message->FindBool ("udp_scan");
			WritePrefs ();
			break;
		default:
			BWindow::MessageReceived (message);
	}
	if ( statusUpdate == true ) {
		fStatusText << "\n";
		fStatusTextView->SetText (fStatusText.String(), fStatusText.Length(), NULL);
		fStatusTextView->ScrollTo (0, 10000);

	}
}

void NetWindow::AboutMenu ()
{
	BAlert *alert = new BAlert ("About Tiki", ABOUTMENUTEXT, "You Da Man!", NULL, NULL, B_WIDTH_FROM_LABEL, B_INFO_ALERT);
	alert->Go ();
}

bool NetWindow::Portscan ()
{
	char	retbuf[1024];
	
	if ( pre_ping == true ) {
		if ( CPing (retbuf, (char *)fHostIP.String(), 32) == -1 ) {
			BAlert *alert = new BAlert ("NetError", "Remote computer doesn't appear to be up.\nContinue scanning?", "Yes", "No", NULL, B_WIDTH_AS_USUAL, B_WARNING_ALERT);
			if ( alert->Go () == 1 ) {
				return false;
			}			
		}
	}
	fStatusText << "Scanning " << fHostName << " (" << fHostIP << ")";
	fStatusText << " ports " << start_port << "~" << end_port << "\n";
	fStatusText << "tcp: ";
	fStatusTextView->SetText (fStatusText.String(), fStatusText.Length(), NULL);
	fStatusTextView->ScrollTo (0, 10000);
	
	numtports = 0;
	SpawnTCPScanner ();

	return true;
}

void NetWindow::PrefsMenu ()
{
	PrefsWindow		*fPrefsWindow;
	BRect		aRect;
	
	aRect = Frame ();
	aRect.InsetBy (30, 40);
	aRect.right = aRect.left + 220;
	aRect.bottom = aRect.top + 285;
	fPrefsWindow = new PrefsWindow (aRect, num_pings, ping_size, start_port, end_port, pre_ping, udp_scan);
	
	fPrefsWindow->Show ();
}

void NetWindow::DNSLookup ()
{
	fStatusText << "Hostname: " << fHostName << "\nIP Addr: " << fHostIP << "\n";
	fStatusTextView->ScrollTo (0, 1000);
	for ( int x = 0; fHostAliases[x].Length() > 0; x++ ) {
		if ( fHostAliases[x].Compare(fHostName) != 0 ) {
			fStatusText << "Host Alias: " << fHostAliases[x].String() << "\n";
			fStatusTextView->ScrollTo (0, 10000);
		}
	}
	for ( int y = 1; fHostAddresses[y].Length() > 0; y++ ) {
		fStatusText << "Alt Address: " << fHostAddresses[y].String() << "\n";
		fStatusTextView->ScrollTo (0, 10000);
	}
}
