#include "NetTool.h"

thread_id		ping_thread = 0;

double CPing ( char *returntxt, char *target, int ping_size ) {
	BString				pingText ("thisissampletext");
	BString				resulttxt;
	int					bytes;
	int					sock;
	struct	sockaddr_in	whereto;
	struct	hostent		*hp;
	struct	timeval		timeout;
	fd_set				mask;
	struct sockaddr_in	from;
	int					fromlen;
	char				inpack[ping_size];
	bigtime_t			sendtime;
	bigtime_t			recvtime;
	
	while ( pingText.Length() < ping_size ) {
		pingText.Append ("thisissampletext");
	}

	if ( pingText.Length() > ping_size ) {
		pingText.Truncate (ping_size, true);
	}

	uint32	ip = inet_addr (target);

	if ( (sock = socket(AF_INET, SOCK_DGRAM, IPPROTO_ICMP)) < 0) {
		herror("socket");
		return -1;
	}
	
	hp = gethostbyaddr ((char *)&ip, 4, AF_INET);
	if ( ! hp ) {
		hp = gethostbyname (target);
		if ( ! hp ) {
			herror ("gethostbyaddr");
			//shutdown (sock, //shutdown_BOTH);
			closesocket (sock);
			return -1;
		}
	}
	
	memset(&whereto, 0, sizeof(whereto));
	
	whereto.sin_family = hp->h_addrtype;
	if (hp->h_length > (int)sizeof(whereto.sin_addr)) {
		hp->h_length = sizeof(whereto.sin_addr);
	}
	
	memcpy(&whereto.sin_addr, hp->h_addr, hp->h_length);
	
	sendtime = real_time_clock_usecs ();
	bytes = sendto (sock, pingText.String(), pingText.Length(), 0, (struct sockaddr *)&whereto, sizeof(whereto));
	if ( bytes != pingText.Length() )  {
		herror ("sendto");
		//shutdown (sock, //shutdown_BOTH);
		closesocket (sock);
		return -1;
	}
	
	FD_ZERO(&mask);
	FD_SET(sock, &mask);
	timeout.tv_sec = 2;
	timeout.tv_usec = 0;

	if ( select(sock+1, &mask, NULL, NULL, &timeout) < 1 ) {
		sprintf (returntxt, "ping timeout\n" );
		//shutdown (sock, //shutdown_BOTH);
		closesocket (sock);
		return -1;
	}
	recvtime = real_time_clock_usecs ();

	fromlen = sizeof(from);
	bytes = recvfrom (sock, inpack, sizeof(inpack), 0, (struct sockaddr *)&from, &fromlen);
	if (bytes < 0) {
		herror ("recvfrom");
		//shutdown (sock, //shutdown_BOTH);
		closesocket (sock);
		return -1;
	} else {
		BString	in (inpack);
		if (in.Compare(pingText, pingText.Length()) == 0) {
			sprintf (returntxt, "%li bytes received in %2.3f msecs\n", pingText.Length(), (double)(recvtime-sendtime)/1000);
		} else {
			herror ("Data doesn't match");
			//shutdown (sock, //shutdown_BOTH);
			closesocket (sock);
			return -1;
		}
	}

	//shutdown (sock, //shutdown_BOTH);
	closesocket (sock);
return (double)((double)(recvtime-sendtime)/1000);
}

int32 Pinger ( void *data ) {
	BMessage	*aMessage = new BMessage (PINGDATA_MSG);
	char		recvbuf[1024];
	thread_id	caller;
	char		retbuf[1024];
	int			sbpos = 0;
	int			newsbpos = 0;
	int			retpings = 0;
	double		ttime = 0;
	double		allttimes[31];
	double		minttime = 0;
	double		maxttime = 0;
	double		avgttime = 0;
	
	memset (allttimes, 0, sizeof(allttimes));
	
	memset (recvbuf, 0, sizeof(recvbuf));
	receive_data ( &caller, recvbuf, sizeof(recvbuf) );
	int num_pings = atoi (recvbuf);

	memset (recvbuf, 0, sizeof(recvbuf));
	receive_data ( &caller, recvbuf, sizeof(recvbuf) );
	int ping_size = atoi (recvbuf);

	for ( int x = 1; x <= num_pings; x++ ) {
		aMessage = new BMessage(PINGDATA_MSG);
		memset (retbuf, 0, sizeof(retbuf));
		ttime = CPing (retbuf, (char *)data, ping_size);
		aMessage->AddString ("result", retbuf);
		if ( ttime > 0 ) {
			allttimes[x] = ttime;
			retpings++;
			if ( x != num_pings+1 ) {
				snooze (1000000);
			}
		}
		newsbpos = (int)(((double)x/(double)num_pings)*100);
		if ( newsbpos > sbpos ) {
			aMessage->AddInt8 ("sbupdate", (newsbpos-sbpos));
			sbpos = newsbpos;
		}
		be_app->PostMessage (aMessage);
	}
	
	if ( retpings > 0 ) {
		for ( int x = 1; x <= num_pings; x++ ) {
			if ( allttimes[x] > 0 ) {
				if ( minttime == 0 ) { minttime = allttimes[x]; }
				if ( maxttime == 0 ) { maxttime = allttimes[x]; }
				if ( allttimes[x] < minttime ) { minttime = allttimes[x]; }
				if ( allttimes[x] > maxttime ) { maxttime = allttimes[x]; }
				avgttime += allttimes[x];
			}
		}
		avgttime /= retpings;
	}
	
	BMessage	*bMessage = new BMessage (PINGTHREAD_EXIT);
	memset (retbuf, 0, sizeof(retbuf));
	sprintf (retbuf, "%i/%i (%3.0f%%)", retpings, num_pings, ((double)(retpings/num_pings)*(double)100));
	bMessage->AddString ("pingstats", retbuf);
	bMessage->AddDouble ("minttime", minttime);
	bMessage->AddDouble ("avgttime", avgttime);
	bMessage->AddDouble ("maxttime", maxttime);
	be_app->PostMessage (bMessage);
return B_OK;
}

void NetWindow::KillPinger () {
kill_thread (ping_thread);
}

void NetWindow::PingMaster ()
{
	BString		pingResult;
	char		sendbuf[1024];
	
	fStatusText << "Pinging " << fHostName << " (" << fHostIP << ")\n";
	fStatusTextView->SetText (fStatusText.String(), fStatusText.Length(), NULL);
	fStatusTextView->ScrollTo (0, 10000);

	ping_thread = spawn_thread (Pinger, "Pinger", B_NORMAL_PRIORITY, (void *)fHostIP.String());
	memset (sendbuf, 0, sizeof(sendbuf));
	sprintf (sendbuf, "%i", num_pings);
	send_data (ping_thread, 420, sendbuf, strlen(sendbuf));
	resume_thread (ping_thread);
	memset (sendbuf, 0, sizeof(sendbuf));
	sprintf (sendbuf, "%i", ping_size);
	send_data (ping_thread, 420, sendbuf, strlen(sendbuf));

}
