#include "NetTool.h"


void NetWindow::AddPrefsInt32 ( PrefsDB *prefs, char *name, int32 value ) {
	status_t	rc;
	#ifdef DEBUG
		printf ("AddInt32: %s => %li\n", name, value);
	#endif
	rc = prefs->ReplaceInt32 (name, value);
	if ( rc != B_OK ) {
		PrefsError ("error setting prefs value", fAppLocation.String());
	}

}

void NetWindow::AddPrefsBool ( PrefsDB *prefs, char *name, bool value ) {
	status_t	rc;
	#ifdef DEBUG
		printf ("AddBool: %s => %i\n", name, value);
	#endif
	rc = prefs->ReplaceBool (name, value);
	if ( rc != B_OK ) {
		PrefsError ("error setting prefs value", fAppLocation.String());
	}

}

void NetWindow::AddPrefsBPoint ( PrefsDB *prefs, char *name, BPoint value ) {
	status_t	rc;
	#ifdef DEBUG
		printf ("AddBPoint: %s => %f,%f\n", name, value.x, value.y);
	#endif
	rc = prefs->ReplaceBPoint (name, value);
	if ( rc != B_OK ) {
		PrefsError ("error setting prefs value", fAppLocation.String());
	}

}

void NetWindow::WriteWindowMovedPrefs () {

	prefs->SetAutoSync (false);
	AddPrefsInt32 (prefs, WINLOCX_KEYWORD, Frame().left);
	AddPrefsInt32 (prefs, WINLOCY_KEYWORD, Frame().top);
	prefs->SetAutoSync (true);

}

void NetWindow::WriteWindowResizedPrefs () {

	prefs->SetAutoSync (false);
	AddPrefsInt32 (prefs, WINSIZEX_KEYWORD, Bounds().right);
	AddPrefsInt32 (prefs, WINSIZEY_KEYWORD, Bounds().bottom);
	prefs->SetAutoSync (true);

}

void NetWindow::WritePrefs () {

	prefs->SetAutoSync (false);
	
	AddPrefsInt32 (prefs, NUMPINGS_KEYWORD, (int32)num_pings);
	AddPrefsInt32 (prefs, PINGSIZE_KEYWORD, (int32)ping_size);
	AddPrefsInt32 (prefs, STARTPORT_KEYWORD, (int32)start_port);
	AddPrefsInt32 (prefs, ENDPORT_KEYWORD, (int32)end_port);
	
	AddPrefsInt32 (prefs, WINSIZEX_KEYWORD, Bounds().right);
	AddPrefsInt32 (prefs, WINSIZEY_KEYWORD, Bounds().bottom);
	AddPrefsInt32 (prefs, WINLOCX_KEYWORD, Frame().left);
	AddPrefsInt32 (prefs, WINLOCY_KEYWORD, Frame().top);

	AddPrefsBool (prefs, PREPING_KEYWORD, pre_ping);
	AddPrefsBool (prefs, UDPSCAN_KEYWORD, udp_scan);

	prefs->SetAutoSync (true);

}

void NetWindow::ReadPrefs () {

	num_pings = -1;
	ping_size = -1;
	start_port = -1;
	end_port = -1;
	pre_ping = -1;
	windowx = -1;
	windowy = -1;
	windowh = -1;
	windoww = -1;
	udp_scan = false;
	
	prefs->GetInt32 (NUMPINGS_KEYWORD, (int32 *)&num_pings);
	prefs->GetInt32 (PINGSIZE_KEYWORD, (int32 *)&ping_size);
	prefs->GetInt32 (STARTPORT_KEYWORD, (int32 *)&start_port);
	prefs->GetInt32 (ENDPORT_KEYWORD, (int32 *)&end_port);
	prefs->GetBool (PREPING_KEYWORD, &pre_ping);
	prefs->GetBool (UDPSCAN_KEYWORD, &udp_scan);
	
	prefs->GetInt32 (WINSIZEX_KEYWORD, (int32 *)&windoww);
	prefs->GetInt32 (WINSIZEY_KEYWORD, (int32 *)&windowh);
	prefs->GetInt32 (WINLOCX_KEYWORD, (int32 *)&windowx);
	prefs->GetInt32 (WINLOCY_KEYWORD, (int32 *)&windowy);
	
	#ifdef DEBUG
		printf ("%s => %i\n", NUMPINGS_KEYWORD, num_pings);
		printf ("%s => %i\n", PINGSIZE_KEYWORD, ping_size);
		printf ("%s => %i\n", STARTPORT_KEYWORD, start_port);
		printf ("%s => %i\n", ENDPORT_KEYWORD, end_port);
		
		printf ("%s => %i\n", PREPING_KEYWORD, pre_ping);
		printf ("%s => %i\n", UDPSCAN_KEYWORD, udp_scan);
		printf ("%s => %i\n", WINSIZEX_KEYWORD, windowh);
		printf ("%s => %i\n", WINSIZEY_KEYWORD, windoww);
		printf ("%s => %i\n", WINLOCX_KEYWORD, windowx);
		printf ("%s => %i\n", WINLOCY_KEYWORD, windowy);

	#endif
	
	if ( start_port == -1 ) {
		start_port = DEF_STARTPORT;
	}
	if ( end_port == -1 ) {
		end_port = DEF_ENDPORT;
	}
	if ( num_pings == -1 ) {
		num_pings = DEF_NUMPINGS;
	}
	if ( ping_size == -1 ) {
		ping_size = DEF_PINGSIZE;
	}
	if ( windowx == -1 ) {
		windowx = DEF_WINDOWX;
	}
	if ( windowy == -1 ) {
		windowy = DEF_WINDOWY;
	}
	if ( windoww == -1 ) {
		windoww = DEF_WINDOWW;
	}
	if ( windowh == -1 ) {
		windowh = DEF_WINDOWH;
	}
	
}

void NetWindow::PrefsError ( const char *texta, const char *textb ) {

	BString		errString (texta);
	
	errString << " " << textb;
	BAlert *alert = new BAlert ("PrefsError", errString.String (), "Wasup wit dat", NULL, NULL, B_WIDTH_FROM_LABEL, B_STOP_ALERT);
	alert->Go ();
}