#include "NetTool.h"

CSlider::CSlider ( BRect frame, const char *name, const char *label, BMessage *message, uint32 min, uint32 max, thumb_style style )
	: BSlider ( frame, name, label, message, min, max, style )
{
	BString bufstring;
	bufstring << Value ();
	fStringView = new BStringView (BRect(100, 2, 120, 13),"numpingText", bufstring.String(), B_FOLLOW_TOP, B_WILL_DRAW);
	AddChild(fStringView);
}

void CSlider::DrawSlider () {
	BSlider::DrawSlider ();
	if ( atoi(fStringView->Text ()) != Value () ) {
		BString bufstring;
		bufstring << Value ();
		fStringView->SetText (bufstring.String());
	}
}

PrefsWindow::PrefsWindow ( BRect frame, int num_pings, int ping_size, int start_port, int end_port, bool pre_ping, bool udp_scan )
	: BWindow ( frame, "NetLookup Options", B_FLOATING_WINDOW_LOOK, B_MODAL_APP_WINDOW_FEEL, B_NOT_RESIZABLE | B_NOT_ZOOMABLE, B_CURRENT_WORKSPACE)
{
	BView		*prefsview;
	BRect		aRect;
	BButton		*aButton;
	BString		aString;
	
	const rgb_color GRAY_BG     = { 220, 220, 220, 255 };
	const rgb_color BAR_BG     = { 200, 200, 245, 255 };
	const rgb_color BAR_FILL     = { 245, 200, 200, 255 };

	aRect = Bounds();
	prefsview = new BView (aRect, "PrefsView", B_FOLLOW_ALL, B_WILL_DRAW);

	Lock ();
	AddChild (prefsview);
	Unlock ();

	prefsview->SetViewColor (GRAY_BG);

	BBox *bb = new BBox (BRect(5,5,aRect.Width()-5,120), NULL, B_FOLLOW_LEFT | B_FOLLOW_TOP, B_WILL_DRAW, B_FANCY_BORDER);
	bb->SetLabel ("Ping Options");
	prefsview->AddChild (bb);

	fNumPingSlider = new CSlider (BRect(5,20,200,50), "numping", "Number of Pings:", new BMessage(NUMPING_CHG_MSG), 1, 30, B_TRIANGLE_THUMB);
	fNumPingSlider->SetHashMarks(B_HASH_MARKS_BOTTOM);
	fNumPingSlider->SetHashMarkCount(30);
	fNumPingSlider->SetLimitLabels("1", "30");
	fNumPingSlider->SetValue (num_pings);
	fNumPingSlider->SetBarColor (BAR_BG);
	fNumPingSlider->UseFillColor (true, &BAR_FILL);
	bb->AddChild(fNumPingSlider);

	aString.Truncate (0, true);
	aString << ping_size;
	fPingSizeTextField = new BTextControl (BRect(5, 80, 200, 100), "PSTextField", "Ping Data Size(bytes):", "", new BMessage(PINGSIZE_CHG_MSG));
	fPingSizeTextField->SetDivider (150);
	fPingSizeTextField->SetText (aString.String());
	bb->AddChild (fPingSizeTextField);


	bb = new BBox (BRect(5,125,aRect.Width()-5,240), NULL, B_FOLLOW_LEFT | B_FOLLOW_TOP, B_WILL_DRAW, B_FANCY_BORDER);
	bb->SetLabel ("Portscan Options");
	prefsview->AddChild (bb);

	aString.Truncate (0, true);
	aString << start_port;
	fStartPortTextField = new BTextControl (BRect(5, 20, 200, 40), "SPTextField", "Starting port#:", "", new BMessage(PORTSTART_CHG_MSG));
	fStartPortTextField->SetDivider (150);
	fStartPortTextField->SetText (aString.String());
	bb->AddChild (fStartPortTextField);

	aString.Truncate (0, true);
	aString << end_port;
	fEndPortTextField = new BTextControl (BRect(5, 45, 200, 65), "EPTextField", "Ending port#:", "", new BMessage(PORTEND_CHG_MSG));
	fEndPortTextField->SetDivider (150);
	fEndPortTextField->SetText (aString.String());
	bb->AddChild (fEndPortTextField);

	fPrePingCheckBox = new BCheckBox (BRect(5, 70, 200, 85), "prescanPing", "Ping hosts before scanning", new BMessage(PSPING_CHECKBOX_MSG));
	fPrePingCheckBox->SetValue (pre_ping);
	bb->AddChild (fPrePingCheckBox);

	fUDPCheckBox = new BCheckBox (BRect(5, 90, 200, 105), "UDPscan", "Include UDP scan", new BMessage(PSUDP_CHECKBOX_MSG));
	fUDPCheckBox->SetValue (udp_scan);
	bb->AddChild (fUDPCheckBox);

	aButton = new BButton (BRect(10, 250, 70, 270), "prefsDefaultsbutton", "Defaults", new BMessage(PREFSDEFAULTS_BUTTON_MSG), B_FOLLOW_TOP, B_WILL_DRAW | B_NAVIGABLE);
	prefsview->AddChild (aButton);

	aButton = new BButton (BRect(80, 250, 135, 270), "prefsCancelbutton", "Cancel", new BMessage(PREFSCANCEL_BUTTON_MSG), B_FOLLOW_TOP, B_WILL_DRAW | B_NAVIGABLE);
	prefsview->AddChild (aButton);

	aButton = new BButton (BRect(150, 250, 205, 270), "prefsOKbutton", "OK", new BMessage(PREFSOK_BUTTON_MSG), B_FOLLOW_TOP, B_WILL_DRAW | B_NAVIGABLE);
	aButton->MakeDefault (true);
	prefsview->AddChild (aButton);

	Show ();
}

void PrefsWindow::MessageReceived (BMessage *message)
{
	BString		bufstring;
	BMessage	*aMessage;
	
	switch (message->what) {
		case PREFSCANCEL_BUTTON_MSG:
			Quit ();
			break;
		case PREFSDEFAULTS_BUTTON_MSG:
			bufstring.Truncate (0, true);
			bufstring << DEF_NUMPINGS;
			fNumPingSlider->SetValue (DEF_NUMPINGS);
			bufstring.Truncate (0, true);
			bufstring << DEF_PINGSIZE;
			fPingSizeTextField->SetText (bufstring.String());
			bufstring.Truncate (0, true);
			bufstring << DEF_STARTPORT;
			fStartPortTextField->SetText (bufstring.String());
			bufstring.Truncate (0, true);
			bufstring << DEF_ENDPORT;
			fEndPortTextField->SetText (bufstring.String());
			fPrePingCheckBox->SetValue (DEF_PREPING);
			fUDPCheckBox->SetValue (DEF_UDPSCAN);
			break;
		case PREFSOK_BUTTON_MSG:
			aMessage = new BMessage (NEW_PREFS_MSG);
			aMessage->AddInt32 ("num_pings", fNumPingSlider->Value ());
			aMessage->AddInt32 ("ping_size", atoi(fPingSizeTextField->Text()));
			aMessage->AddInt32 ("start_port", atoi(fStartPortTextField->Text()));
			aMessage->AddInt32 ("end_port", atoi(fEndPortTextField->Text()));
			aMessage->AddBool ("pre_ping", fPrePingCheckBox->Value());
			aMessage->AddBool ("udp_scan", fUDPCheckBox->Value());
			be_app->PostMessage (aMessage, be_app);
			Quit ();
			break;
		default:
			BWindow::MessageReceived (message);
	}
}